@@ -147,14 +147,13 @@ class Bleachbit(Gtk.Application):
 
     def _init_windows_misc(self, auto_exit, shred_paths, uac):
         application_id_suffix = ''
+        is_context_menu_executed = auto_exit and shred_paths
         if os.name == 'nt':
             if Windows.elevate_privileges(uac):
                 # privileges escalated in other process
                 sys.exit(0)
-            if portable_mode:
-                Windows.copy_fonts_in_portable_app(auto_exit)
 
-            if auto_exit and shred_paths:
+            if is_context_menu_executed:
                 # When we have a running application and executing the Windows
                 # context menu command we start a new process with new application_id.
                 # That is because the command line arguments of the context menu command
@@ -364,11 +363,10 @@ class Bleachbit(Gtk.Application):
         dialog.show_all()
         while True:
             rc = dialog.run()
-            if rc == 100:
-                clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
-                clipboard.set_text(txt, -1)
-            else:
+            if rc != 100:
                 break
+            clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
+            clipboard.set_text(txt, -1)
         dialog.destroy()
 
     def do_activate(self):
@@ -557,6 +555,8 @@ class GUI(Gtk.ApplicationWindow):
     def __init__(self, auto_exit, *args, **kwargs):
         super(GUI, self).__init__(*args, **kwargs)
 
+        self._show_splash_screen()
+
         self._auto_exit = auto_exit
 
         self.set_wmclass(APP_NAME, APP_NAME)
@@ -587,6 +587,19 @@ class GUI(Gtk.ApplicationWindow):
 
         GLib.idle_add(self.cb_refresh_operations)
 
+    def _show_splash_screen(self):
+        if os.name != 'nt':
+            return
+
+        font_conf_file = Windows.get_font_conf_file()
+        if not os.path.exists(font_conf_file):
+            logger.error('No fonts.conf file')
+            return
+
+        has_cache = Windows.has_fontconfig_cache(font_conf_file)
+        if not has_cache:
+            Windows.splash_thread.start()
+
     def _confirm_delete(self, mention_preview, shred_settings=False):
         if options.get("delete_confirmation"):
             return GuiBasic.delete_confirmation_dialog(self, mention_preview, shred_settings=shred_settings)
@@ -726,9 +739,10 @@ class GUI(Gtk.ApplicationWindow):
         from bleachbit import Worker
         self.start_time = None
         if not operations:
-            operations = {}
-            for operation in self.get_selected_operations():
-                operations[operation] = self.get_operation_options(operation)
+            operations = {
+                operation: self.get_operation_options(operation)
+                for operation in self.get_selected_operations()
+            }
         assert isinstance(operations, dict)
         if not operations:  # empty
             GuiBasic.message_dialog(self,
@@ -780,11 +794,9 @@ class GUI(Gtk.ApplicationWindow):
         self.view = display.make_view(
             mdl, self, self.context_menu_event)
         self.view.get_selection().connect("changed", self.on_selection_changed)
-        padding_box = Gtk.Box()
-        padding_box.add(self.view)
         scrollbar_width = scrolled_window.get_vscrollbar().get_preferred_width()[1]
-        padding_box.set_margin_right(scrollbar_width) # avoid conflict with scrollbar
-        scrolled_window.add(padding_box)
+        self.view.set_margin_right(scrollbar_width) # avoid conflict with scrollbar
+        scrolled_window.add(self.view)
         return scrolled_window
 
     def cb_refresh_operations(self):
@@ -826,7 +838,7 @@ class GUI(Gtk.ApplicationWindow):
                     _('Access the application menu by clicking the hamburger icon on the title bar.'))
                 pref = self.get_preferences_dialog()
                 pref.run()
-            if os.name == 'nt':
+            elif os.name == 'nt':
                 self.append_text(
                     _('Access the application menu by clicking the logo on the title bar.'))
             options.set('first_start', False)
@@ -1080,6 +1092,10 @@ class GUI(Gtk.ApplicationWindow):
         return False
 
     def on_show(self, widget):
+
+        if Windows.splash_thread.is_alive():
+            Windows.splash_thread.join(0)
+
         # restore window position, size and state
         if not options.get('remember_geometry'):
             return
