@@ -79,17 +79,15 @@ class LocaleCleanerPath:
         if isinstance(self.pattern, Pattern):
             return (os.path.join(basepath, p) for p in os.listdir(basepath)
                     if self.pattern.match(p) and os.path.isdir(os.path.join(basepath, p)))
-        else:
-            path = os.path.join(basepath, self.pattern)
-            return [path] if os.path.isdir(path) else []
+        path = os.path.join(basepath, self.pattern)
+        return [path] if os.path.isdir(path) else []
 
     def get_localizations(self, basepath):
         """Returns all localization items for this object and all descendant objects"""
         for path in self.get_subpaths(basepath):
             for child in self.children:
                 if isinstance(child, LocaleCleanerPath):
-                    for res in child.get_localizations(path):
-                        yield res
+                    yield from child.get_localizations(path)
                 elif isinstance(child, Pattern):
                     for element in os.listdir(path):
                         match = child.match(element)
@@ -204,6 +202,7 @@ class Locales:
          'hz': 'Otjiherero',
          'ia': 'Interlingua',
          'id': 'Indonesian',
+         'ie': 'Interlingue',
          'ig': 'Asụsụ Igbo',
          'ii': 'ꆈꌠ꒿',
          'ik': 'Iñupiaq',
@@ -427,13 +426,12 @@ def __is_broken_xdg_desktop_application(config, desktop_pathname):
         wineprefix = None
         del execs[0]
         while True:
-            if 0 <= execs[0].find("="):
-                (name, value) = execs[0].split("=")
-                if 'WINEPREFIX' == name:
-                    wineprefix = value
-                del execs[0]
-            else:
+            if execs[0].find("=") < 0:
                 break
+            (name, value) = execs[0].split("=")
+            if name == 'WINEPREFIX':
+                wineprefix = value
+            del execs[0]
         if not FileUtilities.exe_exists(execs[0]):
             logger.info(
                 "is_broken_xdg_menu: executable '%s' does not exist '%s'", execs[0], desktop_pathname)
@@ -560,8 +558,7 @@ def rotated_logs():
                  '/var/log/*/*.old',
                  '/var/log/*.old')
     for globpath in globpaths:
-        for path in glob.iglob(globpath):
-            yield path
+        yield from glob.iglob(globpath)
     regex = '-[0-9]{8}$'
     globpaths = ('/var/log/*-*', '/var/log/*/*-*')
     for path in FileUtilities.globex(globpaths, regex):
